%define anolis_release 1

%global srcname anyio

%global common_description %{expand:
AnyIO is an asynchronous networking and concurrency library that works on top
of either asyncio or trio.  It implements trio-like structured concurrency (SC)
on top of asyncio, and works in harmony with the native SC of trio itself.}

Name:           python-%{srcname}
Version:        3.5.0
Release:        %{anolis_release}%{?dist}
Summary:        Compatibility layer for multiple asynchronous event loop implementations
License:        MIT
URL:            https://github.com/agronholm/anyio
Source:         %pypi_source

# Support for pytest 7
# https://github.com/agronholm/anyio/commit/58fcb0c495
# setup.cfg hunk manually removed (it failed to apply)
Patch:          pytest7.patch

# Skip @asyncio.coroutine tests on Python 3.11+ where it no longer exists
Patch:          https://github.com/agronholm/anyio/pull/431.patch

# Cancel messages are only supported on Python 3.9 and 3.10
# https://github.com/agronholm/anyio/commit/95f43f8db1
Patch:           0001-Fixed-cancel-message-related-test-failure-on-py3.11.patch

BuildArch:      noarch


%description %{common_description}


%package -n python3-%{srcname}
Summary:        %{summary}
BuildRequires:  python3-devel


%description -n python3-%{srcname} %{common_description}


%pyproject_extras_subpkg -n python3-%{srcname} trio


%package -n python3-%{srcname}-doc
Summary:        anyio documentation


%description -n python3-%{srcname}-doc
Documentation for anyio


%prep
%autosetup -n %{srcname}-%{version} -p1

# disable coverage test requirement
sed -e '/coverage/d' -i setup.cfg

# Disable some tests till uvloop is compatible with Python 3.11
# upstream discussion: https://github.com/agronholm/anyio/issues/439
sed -i '/uvloop/d' setup.cfg

# despite the prescense of a pytest "network" marker, socket tests still fail
# without internet access
rm tests/test_sockets.py


%generate_buildrequires
%pyproject_buildrequires -x trio%{?with_tests:,test}%{?with_docs:,doc}


%build
%pyproject_wheel
%if %{with docs}
# generate html docs
PYTHONPATH=${PWD} sphinx-build-3 docs html
# remove the sphinx-build leftovers
rm -rf html/.{doctrees,buildinfo}
%endif


%install
%pyproject_install
%pyproject_save_files %{srcname}


%files -n python3-%{srcname} -f %{pyproject_files}
%license LICENSE


%files -n python3-%{srcname}-doc
%doc README.rst
%if %{with docs}
%doc html
%endif


%changelog
* Tue May 09 2023 Funda Wang <fundawang@yeah.net> - 3.5.0-1
- Import package for anolis 23
